# infer_subc/utils/stats.py
These functions take the segmentations and produce summary statistics with the `skimage.regionprops` 


# infer_subc/utils/stats_helper.py
These _helper_ functions bulk process the segmentations to produce the stats.